@@ -5,12 +5,12 @@
  *	libpgtcl is a tcl package for front-ends to interface with PostgreSQL.
  *	It's a Tcl wrapper for libpq.
  *
- * Portions Copyright (c) 1996-2002, PostgreSQL Global Development Group
+ * Portions Copyright (c) 1996-2003, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql-server/src/interfaces/libpgtcl/Attic/pgtcl.c,v 1.27 2002/09/04 20:31:46 momjian Exp $
+ *	  $Header: /cvsroot/pgsql-server/src/interfaces/libpgtcl/pgtcl.c,v 1.28.4.1 2004/02/02 01:00:58 neilc Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -47,7 +47,7 @@ Pgtcl_Init(Tcl_Interp *interp)
 	 */
 	Tcl_GetDouble(interp, Tcl_GetVar(interp, "tcl_version", TCL_GLOBAL_ONLY), &tclversion);
 	if (tclversion >= 8.1)
-		putenv("PGCLIENTENCODING=UNICODE");
+		Tcl_PutEnv("PGCLIENTENCODING=UNICODE");
 
 	/* register all pgtcl commands */
 	Tcl_CreateCommand(interp,
